@@ -1,22 +1,25 @@
--- Helper functions for the test suite
+--- Helper functions for the test suite
+---
+--- @module test.helpers
 
 -- assert library used by busted
 local assert = require("luassert")
 
--- gloabl varables to set $XDG_CONFIG_HOME and $XDG_DATA_HOME to for the
--- tests.
+--- the temporary directory for the tests
 local tmp = os.getenv("TMPDIR") or "/tmp"
+--- the $XDG_CONFIG_HOME for the tests
 local confdir = tmp .. "/nvimpager-testsuite/no-config"
+--- the $XDG_DATA_HOME for the tests
 local datadir = tmp .. "/nvimpager-testsuite/no-data"
 
--- Run a shell command, assert it terminates with return code 0 and return its
--- output.
---
--- The assertion of the return status works even with Lua 5.1.  The last byte
--- of output of the command *must not* be a decimal digit.
---
--- command: string -- the shell command to execute
--- returns: string -- the output of the command
+--- Run a shell command, assert it terminates with return code 0 and return its
+--- output.
+---
+--- The assertion of the return status works even with Lua 5.1.  The last byte
+--- of output of the command *must not* be a decimal digit.
+---
+--- @param command string -- the shell command to execute
+--- @return string -- the output of the command
 local function run(command)
   -- From Lua 5.2 on we could use io.close to retrieve the return status of
   -- the process.  It would return true, "exit", x where x is the status.
@@ -29,7 +32,8 @@ local function run(command)
   -- https://www.lua.org/manual/5.2/manual.html#pdf-file:close
   -- https://www.lua.org/manual/5.2/manual.html#pdf-os.execute
   -- https://stackoverflow.com/questions/7607384
-  command = string.format("XDG_CONFIG_HOME=%s XDG_DATA_HOME=%s %s; echo $?",
+  command = string.format(
+    "export XDG_CONFIG_HOME=%s XDG_DATA_HOME=%s; (%s) 2>&1; echo $?",
     confdir, datadir, command)
   local proc = io.popen(command)
   if proc == nil then error("Could not open pipe to child process") end
@@ -53,10 +57,10 @@ local function run(command)
   return output:sub(1, -3)
 end
 
--- Read contents of a file and return them.
---
--- filename: string -- the name of the file to read
--- returns: string -- the contents of the file
+--- Read contents of a file and return them.
+---
+--- @param filename string -- the name of the file to read
+--- @return string -- the contents of the file
 local function read(filename)
   local file = io.open(filename)
   if file == nil then error("Could not open file: " .. filename) end
@@ -64,11 +68,11 @@ local function read(filename)
   return contents
 end
 
--- Write contents to a file.
---
--- filename: string -- the name of the file to write
--- contents: string -- the contents to write to the file
--- returns: nil
+--- Write contents to a file.
+---
+--- @param filename string -- the name of the file to write
+--- @param contents string -- the contents to write to the file
+--- @return nil
 local function write(filename, contents)
   local handle = io.open(filename, "w")
   if handle == nil then error("could not open file " .. filename) end
@@ -77,15 +81,15 @@ local function write(filename, contents)
   handle:close()
 end
 
--- Freshly require a nvimpager module, optinally with mocks
---
--- module: string -- the module name under lua/nvimpager to require
--- api: table|nil -- a mock for the neovim api table (:help lua-api)
--- return: table -- the nvimpager module
+--- Freshly require a nvimpager module, optinally with mocks
+---
+--- @param module string -- the module name under lua/nvimpager to require
+--- @param api table|nil -- a mock for the neovim api table (:help lua-api)
+--- @return table -- the nvimpager module
 local function load_nvimpager(module, api)
   -- Create a local mock of the vim module that is provided by neovim.
   local default_api = {
-    nvim_get_hl_by_id = function() return {} end,
+    nvim_get_hl = function() return {} end,
     -- These can return different types so we just default to nil.
     nvim_call_function = function() end,
     nvim_get_option = function() end,
@@ -97,7 +101,10 @@ local function load_nvimpager(module, api)
       if api[key] == nil then api[key] = value end
     end
   end
-  local vim = { api = api }
+  local vim = {
+    api = api,
+    o = setmetatable({}, { __index = function() return "" end })
+  }
   -- Register the api mock in the globals.
   _G.vim = vim
   -- Reload the nvimpager script
@@ -105,6 +112,7 @@ local function load_nvimpager(module, api)
   return require("lua/nvimpager/"..module)
 end
 
+--- @export
 return {
   confdir = confdir,
   datadir = datadir,
